"""Tools for running the AOC problem files generated by aoctools"""

import importlib
import sys

from pathlib import Path


def run(root_path: str, day: int, part: int, debug: bool):
    """
    Runs an AOC problem

    Parameters
    ----------
    root_path
        The path of the root AOC problem directory
    day
        The problem day, e.g., 1, 2, ... 25
    part:
        The problem part, i.e., 1 or 2
    debug:
        Print debug info?
    """

    target_module = f"aoc.d{day:02d}"
    module = importlib.import_module(target_module)

    try:
        target_method = getattr(module, f"p_{part}")
    except AttributeError:
        print(f"__init__.py for module {target_module} must include p_{part}")
        sys.exit(1)

    data_path = Path(root_path, 'data', f"d{day:02d}", 'input.txt')

    with open(data_path, 'r', encoding='utf8') as input_file:
        res = target_method(input_file, debug=debug)
        if res:
            print(f"solution to day {day}, part {part}: {res}")
        else:
            print('no solution found')
            sys.exit(1)
